import 'dart:html' as html;
import 'package:stagexl/stagexl.dart';

Stage stage1 = new Stage(html.querySelector('#stage1'), webGL: true, color: Color.DarkSlateGray, alpha: true);
Stage stage2 = new Stage(html.querySelector('#stage2'), webGL: false, color: Color.DarkSlateGray, alpha: true);
RenderLoop renderLoop = new RenderLoop();
ResourceManager resourceManager = new ResourceManager();

void main() {
  renderLoop.addStage(stage1);
  renderLoop.addStage(stage2);
  new BlendModeSample().addTo(stage1);
  new BlendModeSample().addTo(stage2);
}

//-------------------------------------------------------------------------------------------------

class BlendModeSample extends Sprite {

  var _blendModes = [
    BlendMode.NORMAL, BlendMode.ADD, BlendMode.MULTIPLY, BlendMode.SCREEN,
    BlendMode.ERASE, BlendMode.BELOW, BlendMode.ABOVE, BlendMode.NONE
 ];

  var _blendModeNames = [
    "NORMAL", "ADD", "MULTIPLY", "SCREEN",
    "ERASE", "BELOW", "ABOVE", "NONE (WebGL only)"
  ];

  BlendModeSample() {

    var textFormat = new TextFormat("'Open Sans', sans-serif", 14, Color.White,
        bold:true, align: TextFormatAlign.CENTER, topMargin: 8);

    for(int i = 0; i < _blendModes.length; i++) {

      BlendMode blendMode = _blendModes[i];
      String blendModeName = _blendModeNames[i];

      if (blendMode == BlendMode.BELOW || blendMode == BlendMode.ABOVE) {
        new Bitmap(new BitmapData(160, 100, true, Color.Magenta))
          ..x = 45 + i * 180
          ..y = 90
          ..blendMode = BlendMode.ERASE
          ..addTo(this);

        new Bitmap(new BitmapData(140, 80, true, 0x6060D060))
            ..x = 55 + i * 180
            ..y = 100
            ..addTo(this);
      }

      new TextField(blendModeName, textFormat)
          ..width = 180
          ..height = 200
          ..x = 35 + i * 180
          ..y = 30
          ..border = true
          ..borderColor=Color.White
          ..addTo(this);

      new Sample()
          ..x = 100 + i * 180
          ..y = 115
          ..addTo(this)
          ..blendMode = blendMode;
    }
  }
}

//-------------------------------------------------------------------------------------------------

class Sample extends Sprite {
  Sample() {
    new Circle(0xffff5050)..x =  0..y =  0..addTo(this);
    new Circle(0xff50ff50)..x = 50..y =  0..addTo(this);
    new Circle(0xff5050ff)..x = 25..y = 50..addTo(this);
  }
}

class Circle extends Sprite {
  Circle(int color) {
    this.graphics.beginPath();
    this.graphics.circle(0, 0, 50);
    this.graphics.closePath();
    this.graphics.fillColor(color);
    this.applyCache(-50, -50, 100, 100);
  }
}
